#-----------------------------------------------------------------------------
# Function to draw circular hollow sections (CHS)
#-----------------------------------------------------------------------------

require 'sketchup.rb'
require 'linetool.rb'

#-----------------------------------------------------------------------------

class CylTool26 < LineTool

# 1. The cylinder tool takes a radius (this is 0.5295 inch radius...default 26.9 mm diameter as SU works in inches)

def initialize(radius = 0.5295)
   @radius = radius
   @numsegs = 16
   super()
end

# 2. Define the tube geometry

def create_geometry(pt1, pt2, view)
   model = view.model
   model.start_operation "Create CHS26"
   entities = model.entities

# 3. Input the member name

   prompts1 = ["Name"]
   values1 = ["A1"]
   results = inputbox prompts1,values1,"CHS Tube"
   return if not results    
   member_name = results.to_s

# 4. Set up the layers

   layers = model.layers
   layers.add("Frame")
   layers.add(member_name)
   activelayer = model.active_layer = member_name
   layer = model.active_layer

# 5. Check the centreline vector length

   vec = pt2 - pt1
   length = vec.length
   if( length == 0.0 )
      UI.beep
      puts "Cannot create a zero length tube"
      return
   end

# 6. Create a centreline (for frame stressing)

   cline = entities.add_line pt1, pt2
   newlayer = cline.layer = "Frame"              # set a new layer

# 7. Create a circular cross-section

   circle = entities.add_circle pt1, vec, @radius, @numsegs
   face = entities.add_face circle
   newlayer = face.layer = member_name           # set a new layer

# 8. Do a pushpull to create the tube

   normal = face.normal
   length = -length if( (normal % vec) < 0.0 )
   face.pushpull length

# 9. Add tube data attributes

   activelayer = model.active_layer = "Frame"
   layer = model.active_layer

# 10. Add tube data attributes

   activelayer = model.active_layer = "Frame"
   layer = model.active_layer

   status = cline.set_attribute "Frame","Type","Tube"                # Member Type
   status = cline.set_attribute "Frame","Material","Steel C350"      # Material: Steel
   status = cline.set_attribute "Frame","Section","CHS26"            # Section Type
   status = cline.set_attribute "Frame","Member",member_name         # Member name

   status = cline.set_attribute "Frame","Ymodulus","0"               # Parameters  E = Young's Modulus
   status = cline.set_attribute "Frame","Smodulus","0"               # Parameters  G = Shear Modulus (?)
   status = cline.set_attribute "Frame","Pratio","0"                 # Parameters  P = Poisson's Ratio

   status = cline.set_attribute "Frame","Ax","0"                     # Section Properties  Ax
   status = cline.set_attribute "Frame","Asy","0"                    # Section Properties   Asy
   status = cline.set_attribute "Frame","Asz","0"                    # Section Properties  Asz
   status = cline.set_attribute "Frame","Jxx","0"                    # Section Properties  Jxx
   status = cline.set_attribute "Frame","Iyy","0"                    # Section Properties  Iyy
   status = cline.set_attribute "Frame","Izz","0"                    # Section Properties  Izz

# 11. Complete

   activelayer = model.active_layer = "Layer0"
   layer = model.active_layer
   model.commit_operation
end

end      # class CylTool26

#-----------------------------------------------------------------------------

if( not $chs26_menu_loaded )
    add_separator_to_menu("Draw")
    UI.menu("Draw").add_item("CHS26") {Sketchup.active_model.select_tool CylTool26.new}
    $chs26_menu_loaded = true
end

#-----------------------------------------------------------------------------
